#include "mainwindow.h"
#include "ui_mainwindow.h"

#include <QPen>

#if QWT_VERSION < 0x060000
#include "qdata5f1.h"
#include "qdata5f2.h"
#else
#include "qdataf1.h"
#include "qdataf2.h"
#endif

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    //   
    ui->myPlot->setTitle("QwtPolarPlot Demo");

    //  
    leg = new QwtLegend;
    //   
    leg->setItemMode(QwtLegend::ReadOnlyItem);
    //       
    ui->myPlot->insertLegend(leg,QwtPolarPlot::BottomLegend);

    //  
    grid = new QwtPolarGrid();
    //   
    for (int sc=0; sc < QwtPolar::ScaleCount; sc++)
    {
        //    ,    
        grid->showMinorGrid(sc);
        //  ,       
        grid->setMajorGridPen(sc,QPen(Qt::lightGray));                  //  
        grid->setMinorGridPen(sc,QPen(Qt::lightGray,0,Qt::DotLine));    //  
    }
    //     
    grid->showAxis(QwtPolar::AxisRight,false);
    //     
    grid->showAxis(QwtPolar::AxisTop,true);

    //     
    grid->attach(ui->myPlot);

    //     
    ui->myPlot->setScale(QwtPolar::Radius,0,1,0.2);     //  
    ui->myPlot->setScale(QwtPolar::Azimuth,0,360,30);   //  

    //      "DNA 1"
    curv1 = new QwtPolarCurve(QString("DNA 1"));
    //   2    - -
    curv1->setPen(QPen(Qt::darkGreen,2));

    //      "DNA 2"
    curv2 = new QwtPolarCurve(QString("DNA 2"));
    //    - 
    curv2->setPen(QPen(Qt::red));

    //   
#if QWT_VERSION < 0x060000
    curv1->setData(QData5F1(QwtDoubleInterval(0,360),361));
    curv2->setData(QData5F2(QwtDoubleInterval(0,360),1801));
#else
    curv1->setData(new QDataF1(QwtInterval(0,360),361));
    curv2->setData(new QDataF2(QwtInterval(0,360),1801));
#endif

    //    
    curv1->attach(ui->myPlot);
    curv2->attach(ui->myPlot);

    //   
    pan = new QwtPolarPanner(ui->myPlot->canvas());
    //   
    zoom = new QwtPolarMagnifier(ui->myPlot->canvas());
}

MainWindow::~MainWindow()
{
    //  ,     :
    delete pan;     //  
    delete zoom;    //  

    delete curv1;   //  
    delete curv2;   //  
    delete grid;    //  
    delete leg;     // 

    delete ui;
}
